@@ -40,14 +40,14 @@ NNS.M.reg <- function (X_n, Y, factor.2.dummy = TRUE, order = NULL, stn = NULL,
   minimums <- apply(original.IVs, 2, min)
   maximums <- apply(original.IVs, 2, max)
   
-  dep_a <- tryCatch(NNS.copula(original.matrix), error = function(e) 1)
-  dep_b <- tryCatch(NNS.copula(norm.matrix), error = function(e) 1)
-  dep_c <- tryCatch(mean(unlist(cor(original.matrix)[-1,1])), error = function(e) 1)
+  dep_a <- tryCatch(NNS.copula(original.matrix), error = function(e) .5^n)
+  dep_b <- tryCatch(NNS.copula(norm.matrix), error = function(e) .5^n)
+  dep_c <- tryCatch(mean(unlist(cor(original.matrix)[-1,1])), error = function(e) .5^n)
 
   dependence <- stats::fivenum(c(dep_a, dep_b, dep_c))[4]
   
   if(is.null(order)) order <- max(1, ceiling(dependence*10))
-  if(order >= 9) order <- "max"
+
   
   ###  Regression Point Matrix
   if(is.numeric(order)){
