@@ -86,5 +86,5 @@ NNS.reg(iris[,1:4], iris[,5], residual.plot = FALSE, ncores = 1)$rhs.partitions
 #  [1] 1
 
 ## ----threads, echo = FALSE----------------------------------------------------
-#Sys.setenv("OMP_THREAD_LIMIT" = parallel::detectCores()-1)
+Sys.setenv("OMP_THREAD_LIMIT" = "")
 
